Getting Started
===============

When you access the Coil CMS app, you first need to log in by using your
username and password, which were provided by the administrator.  The first
thing you should do is visiting the :doc:`Account <account>` page and change
your password to secure your account.

When you are done securing your account, you can start working.

On the :doc:`Index <index-page>` page, there are two sections: Posts and Pages.
You can create new posts or edit existing ones.  Depending on the permissions
you were given by the administrator, you may or may not be able to edit posts
created by other users — this may cause an empty list to be displayed.  If you
can see posts by others, but would like to hide them, use the buttons on the
top of the page to switch between display modes.

Each post displays :doc:`Edit <edit>` and :doc:`Delete <delete>` buttons,
which can be used to alter contents.

After performing changes, you need to :doc:`Rebuild <rebuild>` the page in
order to make them visible to the world.  Sometimes, you may not be able to
perform a rebuild yourself and may need the assistance of someone else.  Please
check with your organization for more information.
